pub struct ClGenericFunction { /* private fields */ }Expand description
CL-lite generic function (defgeneric / defmethod) over the dispatch organ.
Implementations
Sourceimpl ClGenericFunction
impl ClGenericFunction
Sourcepub fn add_primary_method(
&mut self,
id: Symbol,
parameter_shapes: Vec<Arc<dyn Shape>>,
body: MethodBody,
) -> Result<()>
pub fn add_primary_method( &mut self, id: Symbol, parameter_shapes: Vec<Arc<dyn Shape>>, body: MethodBody, ) -> Result<()>
Adds a primary method keyed by its parameter shapes.
Sourcepub fn select_primary(
&self,
cx: &mut Cx,
args: &[Value],
) -> Result<MethodSpecificity>
pub fn select_primary( &self, cx: &mut Cx, args: &[Value], ) -> Result<MethodSpecificity>
Selects the most specific primary method for the given arguments.